[gnome-maps] placeStore: sort store by ascending added time



commit 8fcb33d1ba64913fb441700190eed6f91284a24b
Author: Jonas Danielsson <jonas threetimestwo org>
Date:   Wed Jan 22 14:20:41 2014 +0100

    placeStore: sort store by ascending added time
    
    https://bugzilla.gnome.org/show_bug.cgi?id=722825

 src/placeStore.js |    4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)
---
diff --git a/src/placeStore.js b/src/placeStore.js
index 0ce4601..ba11b45 100644
--- a/src/placeStore.js
+++ b/src/placeStore.js
@@ -65,6 +65,8 @@ const PlaceStore = new Lang.Class({
                                GObject.TYPE_STRING,
                                GObject.TYPE_INT,
                                GObject.TYPE_DOUBLE]);
+
+        this.set_sort_column_id(Columns.ADDED, Gtk.SortType.ASCENDING);
     },
 
     addFavorite: function(place) {
@@ -85,7 +87,7 @@ const PlaceStore = new Lang.Class({
             return;
 
         if (this._numRecent === this.recentLimit) {
             // Since all we do is append, the oldest recent will be
             // the first one we encounter.
             this._removeIf((function(model, iter) {
                 let type = model.get_value(iter, Columns.TYPE);
@@ -85,7 +87,7 @@ const PlaceStore = new Lang.Class({
 
         if (this._numRecent === this.recentLimit) {
-            // Since all we do is append, the oldest recent will be
+            // Since we sort by added, the oldest recent will be
             // the first one we encounter.
             this._removeIf((function(model, iter) {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]